@@ -36,7 +36,7 @@
 
 guint progress_timeout_id = 0;
 
-gushort
+gint
 netinfo_get_count (Netinfo * netinfo)
 {
 
@@ -50,7 +50,7 @@ netinfo_get_count (Netinfo * netinfo)
 					       (netinfo->count));
 
 	} else {
-		return 999;
+		return -1;
 	}
 }
 
@@ -175,9 +175,9 @@ netinfo_error_message (Netinfo     * netinfo,
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR,
 					 GTK_BUTTONS_CLOSE,
-					 primary);
+					 "%s", primary);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  secondary ? secondary : " ");
+						  "%s", secondary ? secondary : " ");
 	gtk_window_set_title (GTK_WINDOW (dialog), "");
 
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
@@ -265,6 +265,8 @@ netinfo_text_buffer_insert (Netinfo * netinfo)
 	gchar *dir = g_get_current_dir ();
 	gint child_pid, pout; /* , perr; */
 	GIOChannel *channel;
+	const gchar *charset;
+	GIOStatus status;
 	GError *err = NULL;
 
 	g_return_if_fail (netinfo != NULL);
@@ -284,17 +286,26 @@ netinfo_text_buffer_insert (Netinfo * netinfo)
 
 		/*netinfo->pipe_err = perr; */
 
+		g_get_charset(&charset);
 		channel = g_io_channel_unix_new (pout);
-		g_io_add_watch (channel,
-				G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
-				netinfo_io_text_buffer_dialog, netinfo);
-		g_io_channel_unref (channel);
-
-		/*channel = g_io_channel_unix_new (perr);
-		   g_io_add_watch (channel,
-		   G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
-		   netinfo_io_text_buffer_dialog, netinfo);
-		   g_io_channel_unref (channel); */
+		status = g_io_channel_set_encoding(channel,
+						   charset,
+						   &err);
+		if (G_IO_STATUS_NORMAL == status) {
+			g_io_add_watch (channel,
+					G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
+					netinfo_io_text_buffer_dialog, netinfo);
+			g_io_channel_unref (channel);
+	
+			/*channel = g_io_channel_unix_new (perr);
+			   g_io_add_watch (channel,
+			   G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
+			   netinfo_io_text_buffer_dialog, netinfo);
+			   g_io_channel_unref (channel); */
+		} else {
+			g_warning ("Error: %s\n", err->message);
+			g_error_free (err);
+		}
 	} else {
 		gint len = strlen (err->message);
 
@@ -446,6 +457,8 @@ netinfo_toggle_state (Netinfo * netinfo, gboolean state,
 		netinfo->child_pid = 0;
 		
 		gtk_statusbar_pop (GTK_STATUSBAR (netinfo->status_bar), 0);
+		gtk_statusbar_push (GTK_STATUSBAR (netinfo->status_bar),
+					    0, _("Idle"));
 	} else {
 		pango_font_description_set_weight (font_desc,
 						   PANGO_WEIGHT_BOLD);
